From 812f656ac75052d7371d5d3fe00c33e7a996d34a Mon Sep 17 00:00:00 2001
From: Kris Johnson <11083252+KrisXV@users.noreply.github.com>
Date: Mon, 1 Jul 2024 12:23:44 -0600
Subject: [PATCH] Update various instances of old author names
---
README.md | 2 +-
server/chat-commands/info.ts | 4 ++--
server/chat-plugins/othermetas.ts | 2 +-
server/chat-plugins/randombattles/index.ts | 2 +-
server/chat-plugins/the-studio.ts | 4 ++--
server/chat-plugins/wifi.tsx | 4 ++--
6 files changed, 9 insertions(+), 9 deletions(-)
diff --git a/README.md b/README.md
index f6d12202cb..5696798b1d 100644
--- a/README.md
+++ b/README.md
@@ -89,7 +89,7 @@ Staff
- Andrew Werner [HoeenHero] - Development
- Annika L. [Annika] - Development
- Chris Monsanto [chaos] - Development, Sysadmin
-- Kris Johnson [Kris] - Development
+- Kris Johnson [dhelmise] - Development
- Leonard Craft III [DaWoblefet] - Research (game mechanics)
- Mathieu Dias-Martins [Marty-D] - Research (game mechanics), Development
- Mia A [Mia] - Development
diff --git a/server/chat-commands/info.ts b/server/chat-commands/info.ts
index 5b312305a7..e7ca0c8879 100644
--- a/server/chat-commands/info.ts
+++ b/server/chat-commands/info.ts
@@ -1790,7 +1790,7 @@ export const commands: Chat.ChatCommands = {
if (RANDOMS_CALC_COMMANDS.includes(cmd) ||
(isRandomBattle && !DEFAULT_CALC_COMMANDS.includes(cmd) && !BATTLESPOT_CALC_COMMANDS.includes(cmd))) {
return this.sendReplyBox(
- `Random Battles damage calculator. (Courtesy of Austin)
` +
+ `Random Battles damage calculator. (Courtesy of dhelmise & jetou)
` +
`- Random Battles Damage Calculator`
);
}
@@ -1801,7 +1801,7 @@ export const commands: Chat.ChatCommands = {
);
}
this.sendReplyBox(
- `Pokémon Showdown! damage calculator. (Courtesy of Honko, Austin, & Kris)
` +
+ `Pokémon Showdown! damage calculator. (Courtesy of Honko, Austin, dhelmise, & jetou)
` +
`- Damage Calculator`
);
},
diff --git a/server/chat-plugins/othermetas.ts b/server/chat-plugins/othermetas.ts
index 7a4905469a..3878a8b8a0 100644
--- a/server/chat-plugins/othermetas.ts
+++ b/server/chat-plugins/othermetas.ts
@@ -2,7 +2,7 @@
* Other Metagames chat plugin
* Lets users see elements of Pokemon in various Other Metagames.
* Originally by Spandan.
- * @author Kris
+ * @author dhelmise
*/
import {Utils} from '../../lib';
diff --git a/server/chat-plugins/randombattles/index.ts b/server/chat-plugins/randombattles/index.ts
index ffe80a497a..580b22f2ba 100644
--- a/server/chat-plugins/randombattles/index.ts
+++ b/server/chat-plugins/randombattles/index.ts
@@ -1,6 +1,6 @@
/**
* Random Battles chat-plugin
- * Written by Kris with inspiration from sirDonovan and The Immortal
+ * Written by dhelmise with inspiration from sirDonovan and The Immortal
*
* Set probability code written by Annika
*/
diff --git a/server/chat-plugins/the-studio.ts b/server/chat-plugins/the-studio.ts
index aeb7e8b6e7..604eeb722d 100644
--- a/server/chat-plugins/the-studio.ts
+++ b/server/chat-plugins/the-studio.ts
@@ -2,8 +2,8 @@
* The Studio room chat-plugin.
* Supports scrobbling and searching for music from last.fm.
* Also supports storing and suggesting recommendations.
- * Written by Kris, loosely based on the concept from bumbadadabum.
- * @author Kris
+ * Written by dhelmise, loosely based on the concept from bumbadadabum.
+ * @author dhelmise
*/
import {FS, Net, Utils} from '../../lib';
diff --git a/server/chat-plugins/wifi.tsx b/server/chat-plugins/wifi.tsx
index 40d6fd6343..2d956e93c8 100644
--- a/server/chat-plugins/wifi.tsx
+++ b/server/chat-plugins/wifi.tsx
@@ -1,7 +1,7 @@
/**
* Wi-Fi chat-plugin. Only works in a room with id 'wifi'
* Handles giveaways in the formats: question, lottery, gts
* Written by Kris and bumbadadabum, based on the original plugin as written by Codelegend, SilverTactic, DanielCranham
*/
import {FS, Utils} from '../../lib';
@@ -1024,7 +1024,7 @@ export const commands: Chat.ChatCommands = {
},
},
gtshelp: [
- `GTS giveaways are currently disabled. If you are a Room Owner and would like them to be re-enabled, contact Kris.`,
+ `GTS giveaways are currently disabled. If you are a Room Owner and would like them to be re-enabled, contact dhelmise.`,
],
ga: 'giveaway',
giveaway: {
@@ -1,7 +1,7 @@
* Wi-Fi chat-plugin. Only works in a room with id 'wifi'
* Handles giveaways in the formats: question, lottery, gts
- * Written by Kris and bumbadadabum, based on the original plugin as written by Codelegend, SilverTactic, DanielCranham
+ * Written by dhelmise and bumbadadabum, based on the original plugin as written by Codelegend, SilverTactic, DanielCranham
*/
import {FS, Utils} from '../../lib';